%define epoch	6
%define version	2016f

%define tzdata_version %{version}
%define tzcode_version 2016f

# the zic(8) and zdump(8) manpages are already in man-pages
%define build_manpages 0
%ifarch %mips 
%define build_java 0
%else
%define build_java 1
%endif

%define build_java8 0
%ifnarch %mips
%define build_java8 1
%endif

Summary:	Timezone data
Name:		timezone
Epoch:		%{epoch}
Version:	%{version}
Release:	%mkrel 1
License:	GPL
Group:		System/Base
Source0:	ftp://ftp.iana.org/tz/releases/tzdata%{tzdata_version}.tar.gz
Source1:	ftp://ftp.iana.org/tz/releases/tzcode%{tzcode_version}.tar.gz
Source2:	javazic.tar.gz
Source4:	javazic-1.8-37392f2f5d59.tar.xz
Patch1:		tzdata-extra-tz-links.patch
Patch2:		javazic-fixup.patch
Patch3:		javazic-exclusion-fix.patch
Provides:	tzdata = %{version}-%{release}
Requires(post):	coreutils
BuildRequires:	gawk
BuildRequires:	perl

%description
This package contains data files with rules for various timezones
around the world.

%if %{build_java}
%package java
Summary:	Timezone data for Java
Group:		System/Base
Provides:	tzdata-java = %{version}-%{release}
BuildRequires:	javapackages-tools
BuildRequires:  java-devel
%if %{build_java8}
BuildRequires:	java-1.8.0-devel
BuildArch:	noarch
%endif

%description java
This package contains timezone information for use by Java runtimes.
%endif

%prep
%setup -q -c -a 1
%patch1 -p1 -b .extra-tz-links

%if %{build_java}
mkdir javazic
tar xf %{SOURCE2} -C javazic
pushd javazic
%patch2 -p0 -b .javazic-fixup
%patch3
# Hack alert! sun.tools may be defined and installed in the
# VM. In order to guarantee that we are using IcedTea/OpenJDK
# for creating the zoneinfo files, rebase all the packages
# from "sun." to "rht.". Unfortunately, gcj does not support
# any of the -Xclasspath options, so we must go this route
# to ensure the greatest compatibility.
mv sun rht
for f in `find . -name '*.java'`; do
        sed -i -e 's:sun\.tools\.:rht.tools.:g'\
               -e 's:sun\.util\.:rht.util.:g' $f
done
popd

%if %{build_java8}
tar xf %{SOURCE4}
%endif

echo "tzdata%{tzdata_version}" >> VERSION

# Create zone.info entries for deprecated zone names (#40184)
	chmod +w zone.tab
	echo '# zone info for backward zone names' > zone.tab.new
	while read link cur old x; do
		case $link-${cur+cur}-${old+old}${x:+X} in
		Link-cur-old)
			awk -v cur="$cur" -v old="$old" \
				'!/^#/ && $3 == cur { sub(cur,old); print }' \
				zone.tab || echo ERROR ;;
		Link-*)
			echo 'Error processing backward entry for zone.tab'
			exit 1 ;;
		esac
	done < backward >> zone.tab.new
	if grep -q '^ERROR' zone.tab.new || ! cat zone.tab.new >> zone.tab; then
		echo "Error adding backward entries to zone.tab"
		exit 1
	fi
	rm -f zone.tab.new
%endif

%build

%make TZDIR=%{_datadir}/zoneinfo CFLAGS="%{optflags} -std=gnu99"

grep -v tz-art.htm tz-link.htm > tz-link.html

%if %{build_java}
FILES="africa antarctica asia australasia europe northamerica pacificnew
       southamerica backward etcetera systemv"

# Java 6/7 tzdata
pushd javazic
%{javac} -source 1.5 -target 1.5 -classpath . `find . -name \*.java`
popd
%{java} -classpath javazic/ rht.tools.javazic.Main -V %{version} \
  -d javazi \
  $FILES javazic/tzdata_jdk/gmt javazic/tzdata_jdk/jdk11_backward

%if %{build_java8}
# Java 8 tzdata
pushd javazic-1.8
%{javac} -source 1.7 -target 1.7 -classpath . `find . -name \*.java`
popd

%{java} -classpath javazic-1.8 build.tools.tzdb.TzdbZoneRulesCompiler \
    -srcdir . -dstfile tzdb.dat \
    -verbose \
    $FILES javazic-1.8/tzdata_jdk/gmt javazic-1.8/tzdata_jdk/jdk11_backward
%endif
%endif

%install
make TOPDIR=%{buildroot}/usr \
     TZDIR=%{buildroot}%{_datadir}/zoneinfo \
     ETCDIR=%{buildroot}%{_sbindir} \
     install
rm -f %{buildroot}%{_datadir}/zoneinfo-posix
ln -s . %{buildroot}%{_datadir}/zoneinfo/posix
mv %{buildroot}%{_datadir}/zoneinfo-leaps %{buildroot}%{_datadir}/zoneinfo/right

# nuke unpackaged files
rm -f %{buildroot}%{_datadir}/zoneinfo/localtime
rm -f %{buildroot}%{_sbindir}/tzselect
rm -rf %{buildroot}/usr/{lib,man}

%if %{build_java}
cp -a javazi %{buildroot}%{_datadir}/javazi
%if %{build_java8}
mkdir -p %{buildroot}%{_datadir}/javazi-1.8
install -p -m 644 tzdb.dat %{buildroot}%{_datadir}/javazi-1.8/
%endif
%endif

# install man pages
%if %{build_manpages}
mkdir -p %{buildroot}%{_mandir}/man8
for f in zic zdump; do
install -m 644 $f.8 %{buildroot}%{_mandir}/man8/
done
%endif

%triggerun -- %{name} < 6:2015a-3
# (cg) Transition to symlinked localtime file
if [ ! -L %{_sysconfdir}/localtime -a -f %{_sysconfdir}/sysconfig/clock ]; then
	# Read zone info from (now legacy sysconfig/clock)
	# (the symlink destination is now the canonical way of finding out which
	# timezone we are in)
	unset ZONE
	. %{_sysconfdir}/sysconfig/clock

	if [ -z "$ZONE" ]; then
		ZONE=UTC
	fi

	if [ -f %{_datadir}/zoneinfo/$ZONE ]; then
		ln -sf %{_datadir}/zoneinfo/$ZONE %{_sysconfdir}/localtime
	fi
fi

%post
if [ ! -L %{_sysconfdir}/localtime -a -f %{_datadir}/zoneinfo/UTC ]; then
	ln -s %{_datadir}/zoneinfo/UTC %{_sysconfdir}/localtime
fi

%files
%doc README
%doc Theory
%doc tz-link.html
%{_sbindir}/zdump
%{_sbindir}/zic
%if %{build_manpages}
%{_mandir}/man8/zdump.8*
%{_mandir}/man8/zic.8*
%endif
%dir %{_datadir}/zoneinfo
%{_datadir}/zoneinfo/*

%if %{build_java}
%files java
%{_datadir}/javazi
%if %{build_java8}
%{_datadir}/javazi-1.8
%endif
%endif


%changelog
* Sun Jul 24 2016 luigiwalser <luigiwalser> 6:2016f-1.mga5
+ Revision: 1043516
- 2016f
- tzcode2015f
- tzdata2015f

  + oden <oden>
    - 2016a

* Mon May 04 2015 luigiwalser <luigiwalser> 6:2015d-1.mga5
+ Revision: 821242
- tzcode2015d
- tzdata2015d

* Fri Apr 17 2015 luigiwalser <luigiwalser> 6:2015c-1.mga5
+ Revision: 820377
- tzcode2015c
- tzdata2015c

* Wed Apr 08 2015 luigiwalser <luigiwalser> 6:2015b-1.mga5
+ Revision: 819928
- tzcode2015b
- tzdata2015b

* Tue Feb 10 2015 colin <colin> 6:2015a-3.mga5
+ Revision: 814526
- One-time triggered transition to symlink when sysconfig/clock exits (mga#14888)

* Tue Feb 10 2015 colin <colin> 6:2015a-2.mga5
+ Revision: 814469
- One-time transition to symlink (no need to continually update mga#14888)

  + sander85 <sander85>
    - Use symlinking instead of copying (mga#14888)

  + luigiwalser <luigiwalser>
    - tzcode2015a
    - tzdata2015a

* Thu Nov 20 2014 luigiwalser <luigiwalser> 6:2014j-1.mga5
+ Revision: 798022
- tzcode2014j
- tzdata2014j

* Fri Oct 31 2014 luigiwalser <luigiwalser> 6:2014i-1.mga5
+ Revision: 795027
- tzcode2014i
- tzdata2014i

* Wed Oct 15 2014 umeabot <umeabot> 6:2014h-2.mga5
+ Revision: 741892
- Second Mageia 5 Mass Rebuild

* Tue Oct 14 2014 luigiwalser <luigiwalser> 6:2014h-1.mga5
+ Revision: 738654
- tzcode2014h
- tzdata2014h

* Thu Oct 09 2014 luigiwalser <luigiwalser> 6:2014g-4.mga5
+ Revision: 737751
- remove things not needed when upgrading from mga4 (only when from mga3):
  - pretrans scriplet
  - conflicts with older version of timezone

* Thu Oct 09 2014 tv <tv> 6:2014g-3.mga5
+ Revision: 737744
- do not use %%pretrans when %%pre is enough;
  this add a "interp,pretrans: /bin/sh" dep which breaks installer first transaction

* Tue Sep 16 2014 umeabot <umeabot> 6:2014g-2.mga5
+ Revision: 689890
- Mageia 5 Mass Rebuild

* Sat Sep 06 2014 luigiwalser <luigiwalser> 6:2014g-1.mga5
+ Revision: 672501
- tzcode2014g
- tzdata2014g

* Sun Aug 17 2014 luigiwalser <luigiwalser> 6:2014f-1.mga5
+ Revision: 664527
- tzcode2014f
- tzdata2014f

* Tue Aug 05 2014 luigiwalser <luigiwalser> 6:2014e-2.mga5
+ Revision: 659854
- fix spec file bugs to enable java 1.8 support to build (and enable it now)

* Thu Jul 10 2014 luigiwalser <luigiwalser> 6:2014e-1.mga5
+ Revision: 651078
- tzcode2014e
- tzdata2014e
- add Java 8 support from fedora (disabled currently because it doesn't build)

* Wed Jun 11 2014 luigiwalser <luigiwalser> 6:2014d-1.mga5
+ Revision: 635603
- tzcode2014d
- tzdata2014d

* Fri May 16 2014 luigiwalser <luigiwalser> 6:2014c-1.mga5
+ Revision: 623088
- tzcode2014c
- tzdata2014c

* Sat Mar 29 2014 luigiwalser <luigiwalser> 6:2014b-1.mga5
+ Revision: 609715
- tzcode2014b
- tzdata2014b

* Sat Mar 15 2014 luigiwalser <luigiwalser> 6:2014a-1.mga5
+ Revision: 604016
- tzcode2014a
- tzdata2014a

* Thu Jan 09 2014 luigiwalser <luigiwalser> 6:2013i-2.mga4
+ Revision: 565963
- check for existence of posix link before deleting it (mga#12160)

* Sun Dec 22 2013 luigiwalser <luigiwalser> 6:2013i-1.mga4
+ Revision: 559720
- tzcode2013i
- tzdata2013i

* Thu Nov 07 2013 luigiwalser <luigiwalser> 6:2013h-1.mga4
+ Revision: 549903
- tzcode2013h
- tzdata2013h

* Mon Oct 21 2013 umeabot <umeabot> 6:2013g-2.mga4
+ Revision: 539197
- Mageia 4 Mass Rebuild

* Fri Oct 04 2013 luigiwalser <luigiwalser> 6:2013g-1.mga4
+ Revision: 491573
- tzcode2013g
- tzdata2013g

* Wed Oct 02 2013 tv <tv> 6:2013f-3.mga4
+ Revision: 490439
- fix posix symlink pointing to /usr/share, thus causing libreoffice to loop
  over /usr/share content
- readd conflict
- kill useless self conflict

* Thu Sep 26 2013 luigiwalser <luigiwalser> 6:2013f-2.mga4
+ Revision: 486921
- /usr/share/zoneinfo/posix is now a symlink, fix symlink and conflict

* Thu Sep 26 2013 luigiwalser <luigiwalser> 6:2013f-1.mga4
+ Revision: 486778
- tzcode2013f
- tzdata2013f

* Thu Jul 11 2013 oden <oden> 6:2013d-1.mga4
+ Revision: 453026
- 2013d

* Fri Apr 26 2013 luigiwalser <luigiwalser> 6:2013c-1.mga3
+ Revision: 411309
- tzcode2013c
- tzdata2013c

* Thu Mar 14 2013 luigiwalser <luigiwalser> 6:2013b-1.mga3
+ Revision: 403194
- tzcode2013b
- tzdata2013b

* Mon Jan 14 2013 umeabot <umeabot> 6:2012j-2.mga3
+ Revision: 384582
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jan 05 2013 luigiwalser <luigiwalser> 6:2012j-1.mga3
+ Revision: 338915
- tzcode2012j
- tzdata2012j

* Wed Oct 24 2012 luigiwalser <luigiwalser> 6:2012g-1.mga3
+ Revision: 309653
- tzcode2012f
- tzdata2012f
- adapt to new Makefile (based on fedora)

* Mon Sep 17 2012 luigiwalser <luigiwalser> 6:2012f-1.mga3
+ Revision: 295474
- tzcode2012f
- tzdata2012f

* Sat Sep 01 2012 luigiwalser <luigiwalser> 6:2012e-1.mga3
+ Revision: 287052
- tzcode2012e
- tzdata2012e
- update tzdata-base-0.tar.bz2 (from fedora)
- update source URLs (from opensuse)
- add hack to make version.h

* Sun Apr 15 2012 luigiwalser <luigiwalser> 6:2012c-1.mga2
+ Revision: 230826
- tzcode2012b
- tzdata2012c

* Sun Feb 26 2012 luigiwalser <luigiwalser> 6:2011n-3.mga2
+ Revision: 215055
- fix release to be newer than mga1

* Sun Dec 25 2011 gil <gil> 6:2011n-0.mga2
+ Revision: 187530
- tzdata 2011n

* Tue Nov 01 2011 dmorgan <dmorgan> 6:2011m-0.mga2
+ Revision: 160965
- New version 2011m

* Sat Oct 22 2011 gil <gil> 6:2011l-0.mga2
+ Revision: 157440
- update to 2011l

* Tue Apr 26 2011 ahmad <ahmad> 6:2011g-1.mga1
+ Revision: 91850
- Update tzdata/tzcode to 2011g

* Wed Apr 20 2011 ahmad <ahmad> 6:2011f-1.mga1
+ Revision: 89247
- Update tzcode to 2011e
- Update tzdata to 2011f
- Rediff the extra-tz-links patch

* Sun Jan 09 2011 ahmad <ahmad> 6:2010o-1.mga1
+ Revision: 4459
- drop old conflicts and old macros
- imported package timezone


* Wed Nov 03 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2010o-1mdv2011.0
+ Revision: 592967
- Updated tzdata to 2010o release.

* Mon Oct 25 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2010n-1mdv2011.0
+ Revision: 589280
- Updated tzcode/tzdata to 2010n release.

* Wed Oct 20 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2010m-1mdv2011.0
+ Revision: 587025
- Updated tzcode/tzdata to 2010m release.

* Mon Aug 16 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2010l-1mdv2011.0
+ Revision: 570643
- Updated tzcode/tzdata to 2010l release.

* Thu Aug 05 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2010k-1mdv2011.0
+ Revision: 566062
- Updated tzcode/tzdata to 2010k release.

* Tue Apr 20 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2010i-1mdv2010.1
+ Revision: 537099
- Updated tzdata to 2010i release.

* Mon Apr 05 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2010h-1mdv2010.1
+ Revision: 531771
- Updated tzdata to 2010h release.

* Mon Mar 29 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2010g-1mdv2010.1
+ Revision: 528808
- Updated tzdata to 2010g release.

* Thu Mar 25 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2010f-1mdv2010.1
+ Revision: 527491
- Updated tzcode/tzdata to 2010f release.

* Wed Mar 10 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2010e-1mdv2010.1
+ Revision: 517405
- Updated tzdata to 2010e release.

* Thu Mar 04 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2010c-1mdv2010.1
+ Revision: 514317
- Updated tzcode/tzdata to 2010c release.

* Wed Feb 17 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2010b-1mdv2010.1
+ Revision: 507212
- Updated tzcode to 2010a release.
- Updated tzdata to 2010b release.

* Fri Jan 15 2010 Anssi Hannula <anssi@mandriva.org> 6:2009u-2mdv2010.1
+ Revision: 491853
- default to UTC instead of US Eastern time when no timezone is set

* Mon Dec 28 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009u-1mdv2010.1
+ Revision: 483101
- Updated tzdata to 2009u release.

* Wed Dec 23 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009t-1mdv2010.1
+ Revision: 481877
- Updated tzcode/tzdata to 2009t release.

* Tue Nov 17 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009s-1mdv2010.1
+ Revision: 466966
- Updated tzdata to 2009s release.

* Mon Nov 09 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009r-1mdv2010.1
+ Revision: 463621
- Updated tzcode/tzdata to 2009r release.

* Mon Sep 28 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009n-1mdv2010.0
+ Revision: 450624
- Updated tzdata to 2009n release.

* Mon Sep 28 2009 Olivier Blin <oblin@mandriva.com> 6:2009m-2mdv2010.0
+ Revision: 450397
- do not build java on arm & mips (from Arnaud Patard)

* Thu Sep 10 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009m-1mdv2010.0
+ Revision: 437224
- Updated tzdata to 2009m release.

* Mon Aug 17 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009l-1mdv2010.0
+ Revision: 417350
- Updated tzdata to 2009l release.

* Tue Jul 28 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009k-1mdv2010.0
+ Revision: 402530
- Updated tzcode/tzdata to 2009k release.

* Thu Jun 18 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009j-1mdv2010.0
+ Revision: 387182
- Updated tzdata to 2009j release.

* Fri Jun 12 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009i-1mdv2010.0
+ Revision: 385372
- Updated tzdata/tzcode to 2009i release.

* Tue May 26 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009h-1mdv2010.0
+ Revision: 379963
- Updated tzdata/tzcode to 2009h release.

* Wed May 06 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009g-1mdv2010.0
+ Revision: 372611
- Updated tzdata to 2009g release.

* Fri Apr 17 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009f-1mdv2009.1
+ Revision: 367824
- Updated tzdata to 2009f release.

* Mon Apr 06 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009e-1mdv2009.1
+ Revision: 364522
- Updated tzcode/tzdata to 2009e release.

* Mon Mar 16 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009c-1mdv2009.1
+ Revision: 355928
- Updated tzdata to 2009c release.

* Tue Feb 10 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009b-1mdv2009.1
+ Revision: 339137
- Updated tzcode/tzdata to 2009b release.

* Mon Jan 26 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009a-2mdv2009.1
+ Revision: 333708
- Restore original sysdep-CFLAGS setting in config.mk with optflags.

* Fri Jan 23 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2009a-1mdv2009.1
+ Revision: 333118
- Updated tzcode/tzdata to 2009a
- Removed workaround for #41246, new tzcode has a fix for it.

* Tue Oct 28 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2008i-1mdv2009.1
+ Revision: 297924
- Updated tzdata to 2008i release.

* Tue Oct 14 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2008h-1mdv2009.1
+ Revision: 293757
- Updated tzcode/tzdata to 2008h release.
- Removed already applied tzdata-brazil-decree-6558.patch

* Thu Sep 18 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2008f-1mdv2009.0
+ Revision: 285579
- Updated tzdata to 2008f
- Use now fixed Brazil rule for daylight savings time (decree 6558),
  patch based on a previous one by Frederico A. C. Neves

* Mon Jul 28 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2008e-1mdv2009.0
+ Revision: 251783
- Updated tzcode/tzdata to 2008e release.

* Mon Jul 07 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2008d-1mdv2009.0
+ Revision: 232519
- tzdata update (2008d)
- Workaround gcc 4.3 bug, don't use -O2 optimization flag (#41246).
- Make sure we don't add blank lines to zone.tab to prevent bad parsers
  from crashing (also it isn't clear if blank lines is really allowed),
  as example see bug #41218.

* Wed May 28 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2008c-1mdv2009.0
+ Revision: 212165
- Rediffed tzdata-extra-tz-links patch.
- Added enhanced script to create zone.info entries for deprecated zone
  names (mdv bug #40184), contributed by Ken Pizzini.
- Updated to 2008c.

* Tue Apr 29 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2008b-2mdv2009.0
+ Revision: 199328
- Create zone.info entries for deprecated zone names (#40184).

* Wed Mar 26 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2008b-1mdv2008.1
+ Revision: 190201
- Updated to 2008b.

* Mon Mar 10 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2008a-1mdv2008.1
+ Revision: 183773
- Updated to 2008a.

* Thu Jan 10 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2007k-3mdv2008.1
+ Revision: 147456
- tzdata-base-0.tar.bz2: update tst-timezone.c with the one from
  glibc 2.7
- update-localtime.sh: make sure /etc/localtime has the right
  permissions after copy using install -m (#30045).

* Wed Jan 02 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2007k-2mdv2008.1
+ Revision: 140418
- Updated to 2007k.
- Removed BuildRequires for java-devel-gcj, doesn't seems to be required
  when using java-rpmbuild.

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sun Dec 16 2007 Anssi Hannula <anssi@mandriva.org> 6:2007j-2mdv2008.1
+ Revision: 121034
- buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)

* Thu Dec 06 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2007j-1mdv2008.1
+ Revision: 115994
- Updated to 2007j.

* Mon Nov 05 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2007i-1mdv2008.1
+ Revision: 106148
- Updated to 2007i.
- More cleanups of uneeded spec code and minor define fix.
- Don't place comment inside post -p.

* Fri Oct 12 2007 David Walluck <walluck@mandriva.org> 6:2007h-2mdv2008.1
+ Revision: 97801
- add java sources
- readd java support (this does not force java on the main package)
- Provides: tzdata = %%{version}-%%{release} for Fedora compat
- add Java support (from Fedora) and Provides: tzdata-java = %%{version}-%%{release}

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - Revert previous change, timezone java stuff now has a new entry on
      svn, named timezone-java.

* Mon Oct 01 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2007h-1mdv2008.0
+ Revision: 94275
- Updated to 2007h.
- Removed already applied 2007-2008 Brazil tzdata update.

* Fri Sep 21 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2007g-2mdv2008.0
+ Revision: 91947
- Updated daylight savings time definitions for Brazil (2007/2008). As
  always they keep changing this every year...

* Mon Sep 17 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2007g-1mdv2008.0
+ Revision: 89289
- Updated to 2007g.
- Rediff tzdata-extra-tz-links patch.

* Wed Aug 08 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2007f-2mdv2008.0
+ Revision: 60013
- Cleanup: remove tzdata-tzcode2006a.patch, not needed anymore.

* Wed Jul 18 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 6:2007f-1mdv2008.0
+ Revision: 53155
- spec file clean
- new version
- rediff patch1


* Wed Mar 14 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2007c-2mdv2007.1
+ Revision: 143844
- fix triggers

* Wed Mar 07 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 6:2007c-1mdv2007.1
+ Revision: 134361
- use upstream tz{data,code} 2007c

* Wed Mar 07 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2007c-1mdv
- use upstream tz{data,code} 2007c

